translate.lang.common

Package translate :: Package lang :: Module common |
[hide private]
[frames] | no frames]

# Module common

source code

This module contains all the common features for languages.

# Supported features

- language code (km, af)
- language name (Khmer, Afrikaans)
- Plurals
  - Number of plurals (nplurals)
  - Plural equation
- pofilter tests to ignore

## Segmentation

- characters
- words
- sentences

# TODOs and Ideas for possible features

- Language-Team information
- Segmentation
  - phrases

## Punctuation

- End of sentence
- Start of sentence
- Middle of sentence
- Quotes
  - single
  - double
- Valid characters
- Accelerator characters
- Special characters
- Direction (rtl or ltr)

Classes | [hide private]
| Common This class is the common parent class for all language classes.

Variables | [hide private]
| __package__ = ``'``translate.lang``'``

Imports: re, data